##  Sharing a Presentation
You can share a presentation with other users to foster collaboration and efficient communication on your insights. Follow these steps:
  1. Open the presentation that you want to share, then click Share in the upper-right corner.
  2. In the dialog that appears, enter the names or email addresses of users to share the presentation with, then click Share. From here, you can also copy the presentation link.


![Sharing a Presentation from the Presentation Page](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274ecf737a441014ad2a94a42bb9fecd_LowRes.png)
Sharing a Presentation from the Presentation Page
You can also share a presentation from the presentation preview or the presentation details page.
